@@ -34,6 +34,10 @@ from django_restricted_resource.test_utils import (
 
 from django_restricted_resource.models import RestrictedResource
 
+import django
+if hasattr(django, 'setup'):
+    django.setup()
+
 
 class ResourceCleanTests(FixtureHelper, TestCase):
 
